@@ -1,7 +1,7 @@
 # @Author: chunyang.xu
 # @Email:  398745129@qq.com
 # @Date:   2020-06-03 10:31:36
-# @Last Modified time: 2020-11-30 18:17:17
+# @Last Modified time: 2021-02-01 19:18:38
 # @github: https://github.com/longfengpili
 
 # !/usr/bin/env python3
@@ -9,6 +9,5 @@
 
 from .parse import SqlParse, SqlFileParse
 from .compile import SqlCompile
-from .colmodel import ColumnModel, ColumnsModel
 
-__all__ = ['SqlParse', 'SqlCompile', 'SqlFileParse', 'ColumnModel', 'ColumnsModel']
+__all__ = ['SqlParse', 'SqlCompile', 'SqlFileParse']
